import socket

from zeroconf import ServiceInfo, Zeroconf

service_type = "_http._tcp.local."
server_ip = "192.168.137.1"
server_port = 5000
room_services = ["room2704", "room2705", "room2706", "room2707", "room2708"]

zeroconf = Zeroconf()
ip_address = socket.inet_aton(server_ip)
service_infos = []


def register_services():
    for room in room_services:
        info = ServiceInfo(
            type_=service_type,
            name=f"{room}.{service_type}",
            addresses=[ip_address],
            server=f"{room}.local.",
            port=server_port,
            properties={"path": "/api/endpoints"},
        )
        zeroconf.register_service(info)
        service_infos.append(info)
        print(f"Service {room} is now discoverable on {server_ip}:{server_port}")


if __name__ == "__main__":
    register_services()

    try:
        input("Press enter to exit...\n\n")
    finally:
        for info in service_infos:
            zeroconf.unregister_service(info)
        zeroconf.close()
